pub enum LasmError {
Parse {
message: String,
location: Location,
},
Type(String),
Compile {
message: String,
location: Option<Location>,
},
Runtime(String),
Io(Error),
Module(ModuleError),
}Expand description
Error type for LASM
Variants
Parse
Errors that occur during parsing, with a message and location.
Type(String)
Errors that occur during type checking, with a message.
Compile
Errors that occur during compilation, with a message and optional location.
Runtime(String)
Errors that occur during runtime, with a message.
Io(Error)
Propagated io errors from file reading/writing.
Module(ModuleError)
Propagated Cranelift errors when the cranelift feature is enabled.