pub enum Value {
Int(i64),
Float(f64),
String(String),
Ptr(*mut u8),
Null,
}Expand description
Represents a value that can be passed to or returned from a LASM function.
Variants
Int(i64)
Float(f64)
String(String)
A string value, high level, gets converted to a pointer when passed to the LASM function. String gets never returned.
Ptr(*mut u8)
Null
Implementations